@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from simple_slice_viewer.logger import Logger
-from simple_slice_viewer.observable import Observable
+
 
 from simple_slice_viewer.model import (ImageSlicer, 
                                         SyncedImageSlicers,
@@ -10,7 +10,7 @@ from simple_slice_viewer.model import (ImageSlicer,
                                                 
 
 from simple_slice_viewer.view import (ButtonView, RadioButtonView, 
-                                       IOFusionButtons,
+   
                                        ViewDirectionRadioButtons)
 
 
