@@ -1,8 +1,8 @@
-from simple_slice_viewer.view import WidgetBase
-from PyQt5.QtWidgets import QWidget, QHBoxLayout, QTableView, QLabel, QFileDialog, QLineEdit, QDateEdit, QTimeEdit, QDoubleSpinBox, QRadioButton, QApplication, QPushButton, QCheckBox
+from PyQt5.QtWidgets import (QWidget, QHBoxLayout, QTableView, QLabel,
+                             QFileDialog, QDateEdit, QTimeEdit, QDoubleSpinBox, 
+                             QRadioButton, QPushButton, QCheckBox)
+
 from PyQt5 import QtCore
-from simple_slice_viewer.controller_base import ControllerBase
-from simple_slice_viewer.preset_view import QDialogBase
 from datetime import datetime, time, date
 import sitk_tools
 import SimpleITK as sitk
@@ -12,6 +12,10 @@ import numpy as np
 import pandas as pd
 import qtawesome as qta
 
+from simple_slice_viewer.view import WidgetBase
+from simple_slice_viewer.controller_base import ControllerBase
+from simple_slice_viewer.preset_view import QDialogBase
+
 def set_widget(widget, value, default_value=None):
     if isinstance(widget, QDoubleSpinBox):
         if value is None:
@@ -61,7 +65,8 @@ class FrameTimeModel(QtCore.QAbstractTableModel):
         self._data = data
         
     def headerData(self, section, orientation, role=QtCore.Qt.DisplayRole):
-        if orientation == QtCore.Qt.Horizontal and role == QtCore.Qt.DisplayRole:
+        if orientation == QtCore.Qt.Horizontal\
+            and role == QtCore.Qt.DisplayRole:
             return self._data.columns[section]
         return super().headerData(section, orientation, role)
 
@@ -116,8 +121,7 @@ class IconLabel(QWidget):
         self.setLayout(layout)
 
         self.icon = QLabel()
-        #self.icon.setPixmap(qta.icon(self.get_icon_ok().pixmap(self.IconSize))
-        
+       
         layout.addWidget(self.icon)
         layout.addSpacing(self.HorizontalSpacing)
         layout.addWidget(QLabel(text))
@@ -220,14 +224,22 @@ class SUVWidget(WidgetBase):
         return value_dict
     
     def from_dicom_dict(self, dicom_dict):
+        weight = dicom_dict['PatientWeight']
+        activity = dicom_dict['RadionuclideTotalDose'] / 1E6
+        activity_date = dicom_dict['SeriesDateTime'].date()
+        activity_time = dicom_dict['SeriesDateTime'].time()
+        scan_time = dicom_dict['RadiopharmaceuticalStartDateTime'].time()
+        scan_date = dicom_dict['RadiopharmaceuticalStartDateTime'].date()
+        halflife = dicom_dict['RadionuclideHalfLife'] / 60
+        
         value_dict = {}
-        value_dict[self.WEIGHT] = dicom_dict['PatientWeight']
-        value_dict[self.ACTIVITY] = dicom_dict['RadionuclideTotalDose'] / 1E6
-        value_dict[self.ACTIVITYDATE] = dicom_dict['SeriesDateTime'].date()
-        value_dict[self.ACTIVITYTIME] = dicom_dict['SeriesDateTime'].time()
-        value_dict[self.SCANTIME] = dicom_dict['RadiopharmaceuticalStartDateTime'].time()
-        value_dict[self.SCANDATE] = dicom_dict['RadiopharmaceuticalStartDateTime'].date()
-        value_dict[self.HALFLIFE] = dicom_dict['RadionuclideHalfLife'] / 60
+        value_dict[self.WEIGHT] = weight
+        value_dict[self.ACTIVITY] = activity
+        value_dict[self.ACTIVITYDATE] = activity_date
+        value_dict[self.ACTIVITYTIME] = activity_time
+        value_dict[self.SCANTIME] = scan_time
+        value_dict[self.SCANDATE] = scan_date
+        value_dict[self.HALFLIFE] = halflife
 
         self.from_dict(value_dict)
     
@@ -245,7 +257,8 @@ class SUVWidget(WidgetBase):
         dicom_dict['SeriesDateTime'] = scan_dt
         
         dicom_dict['PatientWeight'] = value_dict[SUVWidget.WEIGHT]
-        dicom_dict['RadionulcideTotalDose'] = value_dict[SUVWidget.ACTIVITY] * 1E6
+        activity = value_dict[SUVWidget.ACTIVITY] * 1E6
+        dicom_dict['RadionulcideTotalDose'] = activity
         return dicom_dict
     
 class LoadOptionsWidget(WidgetBase):
@@ -303,8 +316,9 @@ class LoadOptionsWidget(WidgetBase):
 class LoadPETDialog(QDialogBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.load_options_widget.suv_radio.toggled.connect(self.update_suv_check)
-        self.load_options_widget.bqml_radio.toggled.connect(self.update_suv_check)
+        cbk = self.update_suv_check
+        self.load_options_widget.suv_radio.toggled.connect(cbk)
+        self.load_options_widget.bqml_radio.toggled.connect(cbk)
         self.update_suv_check()
         
     def create_widgets(self):
@@ -399,7 +413,9 @@ class LoadPETController(ControllerBase):
                                                SUV=False, 
                                                frame_tag=frame_tagname, 
                                                recursive=True)
-            frames = [image_dict[key] for key in sorted(list(image_dict.keys()))]
+            items = sorted(list(image_dict.keys()))
+            
+            frames = [image_dict[key] for key in items]
             self.image = sitk.JoinSeries(frames)
         self.view.close()
         return
@@ -478,10 +494,7 @@ class LoadPETController(ControllerBase):
             data[col] = data[col].round(1)
             
         return data
-        
-            
-        
-        
+
                         
     def update(self):
         if not self.folder_is_valid():
@@ -508,17 +521,5 @@ class LoadPETController(ControllerBase):
             self.view.folder_label.setText(self.folder)
         self.update_enabled()
         
-if __name__ == "__main__":
-   
-    
-    app = QApplication([])
-    view = LoadPETDialog()
-    #view.suv_widget.from_dicom_dict(dicom_dict)
-    contr = LoadPETController(view=view)
-    contr.folder = 'D:/PUMP/Arterieel/PET_PUMP2_LEVER_DYN_AC'
-    view.show()
-    app.exec_()
-    
-    view.suv_widget.to_dict()
-        
+
 
