@@ -1,12 +1,11 @@
 from PyQt5.QtCore import QAbstractListModel, pyqtSignal, QObject, Qt
 import math
-from simple_slice_viewer.logger import Logger
 import numpy as np
 import SimpleITK as sitk
 import os
 import sitk_tools
 
-
+from simple_slice_viewer.logger import Logger
 
 SUV = 'SUV'
 CT = 'CT'
@@ -114,9 +113,12 @@ class ImageSlicer(QObject):
         
         index = [math.floor(ii) for ii in index]
         
-        if any([ii<0 for ii in index]):
-            raise IndexError()    
-            
+        for ii, value in enumerate(index):
+            if value < 0:
+                index[ii] = 0
+            if value >= self.get_image().GetSize()[ii]:
+                index[ii] = self.get_image().GetSize()[ii] - 1
+                    
         if len(index) == 2:
             image = self.get_sitk_slice()
         elif len(index) == 3:
