@@ -1,55 +1,67 @@
-from simple_slice_viewer.view import WidgetBase
-from PyQt5.QtWidgets import QScrollBar, QLabel, QComboBox, QLineEdit, QDoubleSpinBox, QRadioButton, QApplication, QPushButton, QCheckBox, QDialog, QGridLayout
+from PyQt5.QtWidgets import  (QLabel, QComboBox, QLineEdit, QDoubleSpinBox, 
+                             QRadioButton, QPushButton, QCheckBox, QGridLayout)
+                               
 from PyQt5.QtCore import  pyqtSignal
-from simple_slice_viewer.preset_model import ColorScale, ImagePreset, ImageFusionPreset, PresetModel
-from PyQt5.QtCore import Qt
 
-PERCENTAGE_MAX_OPTIONS = ['0%', '1%', '5%', '10%', '30%', '50%', '70%', '90%', '95%', '99%', '100%']
+from simple_slice_viewer.preset_model import (ImageFusionPreset, ColorScale, 
+                                              ColorMap, ColorMaps)
+from simple_slice_viewer.view_base import WidgetBase, QDialogBase
+from simple_slice_viewer.view import HorizontalSLider
 
-class QDialogBase(QDialog):
-    _layout = None
-    def __init__(self, parent=None):
-        QDialog.__init__(self, parent)
-        self.create_widgets()
-        self.create_layout()
-        self.create_bottom_layout()
-        self.set_callbacks()
-        self.setLayout(self.layout)
-        self.set_widgets()
-        
+
+PERCENTAGE_MAX_OPTIONS = ['0%', '1%', '5%', '10%', '30%', '50%', 
+                          '70%', '90%', '95%', '99%', '100%']
+
+
+class AvailableColorScaleDialog(QDialogBase):
+    nrows = 15
     def create_widgets(self):
-        pass
+        cmaps = ColorMaps.get_available_colormaps()
+        self.checkboxes = {}
+        for cmap in cmaps:            
+            self.checkboxes[cmap.colormap] = QCheckBox(cmap.colormap)
+            
+        self.apply_button = QPushButton('Apply')
+        self.cancel_button = QPushButton('Cancel')
+        self.setWindowTitle('Available Colormaps')
     
-    def create_layout(self):
-        pass
-    
-    def create_bottom_layout(self):
-        pass
+    def from_list(self, cmaps):
+        for box in self.checkboxes.values():
+            box.setChecked(False)
+            
+        for cmap in cmaps:
+            # if cmap not in self.checkboxes.keys():
+            #     raise KeyError(f'{cmap} not a valid colormap!')   
+            self.checkboxes[cmap.colormap].setChecked(True)
+            
+    def to_list(self):
+        cmaps = []
+        for cmap, box in self.checkboxes.items():
+            if box.isChecked():
+                cmaps += [cmap]
+        return ColorMaps.from_list([ColorMap(colormap=cmap, name=cmap)\
+                                    for cmap in cmaps])
+                                    
     
     def set_callbacks(self):
-        pass
+        self.apply_button.clicked.connect(self.accept)
+        self.cancel_button.clicked.connect(self.reject)
     
-    def set_widgets(self):
-        pass
-
-    @property
-    def layout(self):
-        if self._layout is None:
-            self._layout = self._get_layout_object()
-        return self._layout
-    
-    @layout.setter
-    def layout(self, layout):
-        self._layout = layout
-        
-    
-    def _get_layout_object(self):
-        return QGridLayout()
-    
-    @staticmethod
-    def set_combo_to_text(combo, text):
-        combo.setCurrentIndex(combo.findText(str(text)))
+    def create_layout(self):
+        col = 0
+        row = 0
+        for cbox in self.checkboxes.values():
+            self.layout.addWidget(cbox, row, col)
+            row += 1
+            if row == self.nrows:
+                col += 1
+                row = 0
+                
+        row = self.layout.rowCount()
         
+        self.layout.addWidget(self.apply_button, row, 0)
+        self.layout.addWidget(self.cancel_button, row, 1)
+      
 class PresetSaveDialog(QDialogBase):
     def create_widgets(self):
         self.existing_radio = QRadioButton('Overwrite Existing Preset')
@@ -119,58 +131,11 @@ class PresetSaveDialog(QDialogBase):
         
         # self.layout.addWidget(self.cancel_button, row, 0)
 
-class AvailableColorScaleDialog(QDialogBase):
-    ncols = 5
-    def create_widgets(self):
-        cmaps = ImagePreset.get_available_colormaps()
-        self.checkboxes = {}
-        for cmap in cmaps:
-            self.checkboxes[cmap] = QCheckBox(cmap)
-            
-        self.apply_button = QPushButton('Apply')
-        self.cancel_button = QPushButton('Cancel')
-        self.setWindowTitle('Available Colormaps')
-    
-    def from_list(self, cmaps):
-        for box in self.checkboxes.values():
-            box.setChecked(False)
-            
-        for cmap in cmaps:
-            # if cmap not in self.checkboxes.keys():
-            #     raise KeyError(f'{cmap} not a valid colormap!')            
-            self.checkboxes[cmap].setChecked(True)
-            
-    def to_list(self):
-        cmaps = []
-        for cmap, box in self.checkboxes.items():
-            if box.isChecked():
-                cmaps += [cmap]
-        return cmaps
-    
-    def set_callbacks(self):
-        self.apply_button.clicked.connect(self.accept)
-        self.cancel_button.clicked.connect(self.reject)
-    
-    def create_layout(self):
-        col = 0
-        row = 0
-        for cbox in self.checkboxes.values():
-            self.layout.addWidget(cbox, row, col)
-            col += 1
-            if col == self.ncols:
-                row += 1
-                col = 0
-                
-        row += 1
-        
-        self.layout.addWidget(self.apply_button, row, 0, 1, self.ncols)
-        
-        row += 1
-        
-        self.layout.addWidget(self.cancel_button, row, 0, 1, self.ncols)
+
                 
         
 class RadioButtonGroup(WidgetBase):
+    toggled = pyqtSignal(str)
     def __init__(self, *args, ncols=None):
         self.ncols = ncols
         self.title = args[0]
@@ -183,6 +148,13 @@ class RadioButtonGroup(WidgetBase):
         for name in self.button_names:
       
             self.radio_buttons += [QRadioButton(name)]
+            
+    def set_callbacks(self):
+        for button in self.radio_buttons:
+            button.toggled.connect(self.toggle)
+            
+    def toggle(self):
+        self.toggled.emit(self.str_value())
         
     def create_layout(self):
         self.layout.addWidget(self.title_label, 0, 0)
@@ -211,13 +183,15 @@ class RadioButtonGroup(WidgetBase):
         for name, radio in zip(self.button_names, self.radio_buttons):
             if name == value:
                 radio.setChecked(True)
-    
-    def value(self):
+                
+    def str_value(self):
         for index, radio in enumerate(self.radio_buttons):
             if radio.isChecked():
-                str_value = self.button_names[index]
-                value = float(str_value.replace('%', ''))
-                return value
+                return self.button_names[index]
+    
+    def value(self):        
+        value = float(self.str_value().replace('%', ''))
+        return value
             
             
 class MinMaxRangeWidget(WidgetBase):
@@ -232,6 +206,24 @@ class MinMaxRangeWidget(WidgetBase):
         
         self.layout.addWidget(self.min_radios, row, 0)
         self.layout.addWidget(self.max_radios, row, 1)
+    
+    def min_set(self, value):
+        index = self.min_radios.button_names.index(value)
+        for i, button in enumerate(self.max_radios.radio_buttons):
+            button.setEnabled(i > index)
+    
+    def set_widgets(self):
+        self.min_radios.radio_buttons[-1].setEnabled(False)
+        self.max_radios.radio_buttons[0].setEnabled(False)
+    def max_set(self, value):
+        index = self.max_radios.button_names.index(value)
+        for i, button in enumerate(self.min_radios.radio_buttons):
+            button.setEnabled(i < index)
+
+    def set_callbacks(self):
+        
+        self.min_radios.toggled.connect(self.min_set)
+        self.max_radios.toggled.connect(self.max_set)
         
     def setValues(self, values):
         self.min_radios.setValue(values[0])
@@ -278,50 +270,100 @@ class FixedScaleWidget(WidgetBase):
 
     def values(self):
         return [qvalue.value() for qvalue in self.qvalues.values()]
-
+    
+        
 class ImageFusionPresetDialog(QDialogBase):
 
-    
     def create_widgets(self):
+        self.combo = QComboBox()
         self.preset_label = QLabel('Preset')
-        self.preset_name = QLabel('Preset')
-        self.image_preset_label = QLabel('Image Preset')
-        self.image_preset_combo = QComboBox()
-        self.fusion_preset_label = QLabel('Fusion Preset')
-        self.fusion_preset_combo = QComboBox()
         
+        self.name_label = QLabel('Name')
+        self.preset_name = QLineEdit('Preset')
+        
+        self.image_colorscale_label = QLabel('Image Colorscale')
+        self.image_colorscale_combo = QComboBox()
+        
+        self.image_colormap_label = QLabel('Image Colormap')
+        self.image_colormap_combo = QComboBox()
+        
+        self.fusion_colorscale_label = QLabel('Fusion Colorscale')
+        self.fusion_colorscale_combo = QComboBox()
+        
+        self.fusion_colormap_label = QLabel('Fusion Colormap')
+        self.fusion_colormap_combo = QComboBox()
+        
+        self.alpha_slider = HorizontalSLider()
+        
+
         self.apply_button = QPushButton('Apply')
         self.cancel_button = QPushButton('Cancel')
         self.new_button = QPushButton('New Preset')
         self.delete_button = QPushButton('Delete Preset')
+        
+        self.widgets_enabled = [self.name_label,
+                                self.preset_name,
+                                self.image_colormap_label,
+                                self.image_colorscale_combo,
+                                self.fusion_colormap_label,
+                                self.fusion_colormap_combo,
+                                self.alpha_slider,
+                                self.apply_button,
+                                self.delete_button]
+        
+    def setEnabled(self, enabled):
+        for widget in self.widgets_enabled:
+            widget.setEnabled(enabled)
+        
     def create_layout(self):
         row = 0
-        
         self.layout.addWidget(self.preset_label, row, 0)
+        self.layout.addWidget(self.combo,row , 1)
+        
+        row += 1
+        
+        self.layout.addWidget(self.name_label, row, 0)
         self.layout.addWidget(self.preset_name, row, 1)
+        
+        row += 1
+        self.layout.addWidget(self.image_colorscale_label, row, 0)
+        self.layout.addWidget(self.image_colorscale_combo, row, 1)
         row += 1
         
-        self.layout.addWidget(self.image_preset_label, row, 0)
-        self.layout.addWidget(self.image_preset_combo, row, 1)
+        self.layout.addWidget(self.image_colormap_label, row, 0),
+        self.layout.addWidget(self.image_colormap_combo, row, 1)
         
         row += 1
         
-        self.layout.addWidget(self.fusion_preset_label, row, 0)
-        self.layout.addWidget(self.fusion_preset_combo, row, 1)
+        self.layout.addWidget(self.fusion_colorscale_label, row, 0)
+        self.layout.addWidget(self.fusion_colorscale_combo, row, 1)
         
         row += 1
         
-        self.layout.addWidget(self.new_button, row, 0)
-        self.layout.addWidget(self.delete_button, row, 1)
+        self.layout.addWidget(self.fusion_colormap_label, row, 0)
+        self.layout.addWidget(self.fusion_colormap_combo, row, 1)
+       
         
         row += 1
         
-        self.layout.addWidget(self.apply_button, row, 0)
+        self.layout.addWidget(self.alpha_slider, row, 0, 1, 2)
         
-        # row += 1
+        row += 1
+        
+        self.button_layout = QGridLayout()
+        
+
+        
+        self.button_layout.addWidget(self.new_button, 0, 0)
+        self.button_layout.addWidget(self.delete_button, 0, 1)
+        
+        
+        
+        self.button_layout.addWidget(self.apply_button, 1, 0)
+        self.button_layout.addWidget(self.cancel_button, 1, 1)
+        
+        self.layout.addLayout(self.button_layout, row, 0, 1, 2)
         
-        self.layout.addWidget(self.cancel_button, row, 1)
-    
     def set_callbacks(self):
         
         self.apply_button.clicked.connect(self.accept)
@@ -329,29 +371,45 @@ class ImageFusionPresetDialog(QDialogBase):
         
     def set_widgets(self):
         self.setWindowTitle('Image Fusion Presets')
+        self.alpha_slider.scrollbar.setMinimum(0)
+        self.alpha_slider.scrollbar.setMaximum(100)
     
     def get_preset(self):
-        preset = ImageFusionPreset(name=self.preset_name.text(),
-                                  image_preset=self.image_preset_combo.currentText(),
-                                  fusion_preset=self.fusion_preset_combo.currentText())
+       
+        preset = ImageFusionPreset(
+            name=self.preset_name.text(),
+            image_colormap=self.image_colormap_combo.currentText(),
+            image_colorscale=self.image_colorscale_combo.currentText(),
+            fusion_colormap=self.fusion_colormap_combo.currentText(),
+            fusion_colorscale=self.fusion_colorscale_combo.currentText(),
+            alpha=self.alpha_slider.value())
+ 
+                             
         return preset
     
     def set_preset(self, preset):
+        self.combo.setCurrentText(preset.name)
         self.preset_name.setText(preset.name)
-        self.image_preset_combo.setCurrentText(preset.image_preset)
-        self.fusion_preset_combo.setCurrentText(preset.fusion_preset)
-    
-    
+        self.image_colormap_combo.setCurrentText(preset.image_colormap)
+        self.image_colorscale_combo.setCurrentText(preset.image_colorscale)
         
-class ImagePresetDialog(QDialogBase):
+        self.fusion_colormap_combo.setCurrentText(preset.fusion_colormap)
+        self.fusion_colorscale_combo.setCurrentText(preset.fusion_colorscale)
+        
+        self.alpha_slider.setValue(preset.alpha)
+        
+class ColorScaleDialog(QDialogBase):
     new_preset_event = pyqtSignal()
     delete_preset_event = pyqtSignal()
+    
+   
     def create_widgets(self):
-        
         super().create_widgets()
+        self.combo       = QComboBox()
+        self.colorscale_combo_label = QLabel('Colorscale')
         
-        self.preset_label   = QLabel('Preset Name')
-        self.preset_name    = QLabel('Name')
+        self.preset_label   = QLabel('Colorscale Name')
+        self.preset_name    = QLineEdit('Name')
         
         self.type_minmax    = QRadioButton('Relative to Maximum')
         self.type_wl        = QRadioButton('Window - Level')
@@ -365,27 +423,41 @@ class ImagePresetDialog(QDialogBase):
         self.widget_wl.setRange(-float('inf'), float('inf'))
         
         self.widget_minmax =  MinMaxRangeWidget()
-        
-        # self.save_widget = PresetSaveDialog()
-        
-        self.alpha_slider = QScrollBar(Qt.Horizontal)
-        self.alpha_label = QLabel('0%')
-        
-        self.colormap_label = QLabel('Colormap')
-        
-        self.colormap_combo = QComboBox()
-        self.colormap_button = QPushButton('Add colormaps')
+        self.new_button = QPushButton('New')
+        self.delete_button = QPushButton('Delete')
         self.apply_button = QPushButton('Apply')
         self.cancel_button = QPushButton('Cancel')
-        self.new_button = QPushButton('New Preset')
-        self.delete_button = QPushButton('Delete Preset')
+        
+        #self.colorscale_buttons = ColorscaleButtons()
+      
+        self.widgets_enabled = [self.preset_label,
+                                self.preset_name,
+                                self.type_minmax,
+                                self.type_wl,
+                                self.type_fixed,
+                                self.widget_fixed,
+                                self.widget_wl,
+                                self.widget_minmax,
+                                self.delete_button,
+                                self.apply_button]
         self.setWindowTitle('Image Preset')
         
+        
+    def setEnabled(self, enabled):
+        for widget in self.widgets_enabled:
+            widget.setEnabled(enabled)
+        
     def create_layout(self):
+
         super().create_layout()
        
         row = self.layout.rowCount() + 1
         
+        self.layout.addWidget(self.colorscale_combo_label, row, 0)
+        self.layout.addWidget(self.combo, row, 1)
+            
+        row += 1
+        
         self.layout.addWidget(self.preset_label, row, 0)
         
         self.layout.addWidget(self.preset_name, row, 1)
@@ -413,66 +485,15 @@ class ImagePresetDialog(QDialogBase):
         row += 1
         
         self.layout.addWidget(self.widget_minmax, row, 0, 1, 2)
-        
+     
+       
         row += 1
-        
-        self.layout.addWidget(self.alpha_label, row, 0, 1, 2)
-        
-        row += 1
-        
-        self.layout.addWidget(self.alpha_slider, row, 0, 1, 2)
-        
-        row += 1
-        
-        self.layout.addWidget(self.colormap_label, row, 0, 1, 2)
-        
-        row += 1
-        
-        self.layout.addWidget(self.colormap_combo, row, 0)
-        
-        # row += 1
-        
-        self.layout.addWidget(self.colormap_button, row, 1)
-        # self.layout.addWidget(self.save_widget, row, 0)
-        
-        row += 1
-        
-        self.layout.addWidget(self.new_button, row, 0)
-        self.layout.addWidget(self.delete_button, row, 1)
-        
-        row += 1
-        
-        self.layout.addWidget(self.apply_button, row, 0, 1, 1)
-        
-        # row += 1
-        
-        self.layout.addWidget(self.cancel_button, row, 1, 1, 1)
-    
-
-    def get_alpha(self):
-        return self.alpha_slider.value()
-    
-    def set_alpha(self, alpha):
-        self.alpha_slider.setValue(alpha)
-        
-    def update_alpha_label(self, value):
-        self.alpha_label.setText(f'Alpha: { int(value)}%')
-        
-    def showsave_diaolog(self):
-        dlg = PresetSaveDialog()
-        dlg.exec_()
-        
-    def set_widgets(self):
-        self.colormap_combo.addItems(ImagePreset.get_available_colormaps())
-        self.alpha_slider.setMinimum(0)
-        self.alpha_slider.setMaximum(100)
-  
-    
-    def set_colormap(self, colormap):
-        self.colormap_combo.setCurrentText(colormap)
-        
-    def get_colormap(self):
-        return self.colormap_combo.currentText()
+        self.button_box = QGridLayout()
+        self.button_box.addWidget(self.new_button, 0, 0)
+        self.button_box.addWidget(self.delete_button, 0, 1)
+        self.button_box.addWidget(self.apply_button, 1, 0)
+        self.button_box.addWidget(self.cancel_button, 1, 1)
+        self.layout.addLayout(self.button_box, row, 0, 1, 2)
         
     def _get_scale_types(self):
         return [ColorScale.WINDOW_LEVEL, ColorScale.FIXED, 
@@ -487,45 +508,35 @@ class ImagePresetDialog(QDialogBase):
     def set_callbacks(self):        
         super().set_callbacks()        
         
-        # self.save_button.clicked.connect(self.showsave_diaolog)
         self.type_wl.toggled.connect(self.toggle)
         self.type_minmax.toggled.connect(self.toggle)
         self.type_fixed.toggled.connect(self.toggle)
-        
         self.apply_button.clicked.connect(self.accept)
         self.cancel_button.clicked.connect(self.reject)
-        
-        self.alpha_slider.valueChanged.connect(self.update_alpha_label)
-                
+
     def toggle(self, *args, **kwargs):
         for radio, widget in zip(self._get_radios(), self._get_widgets()):
             enabled = radio.isChecked()         
             widget.setEnabled(enabled)
             
-    def from_model(self, model):
-   
-        self.set_scale_type(model.scale_type)
-        self.set_scale(model.scale)
-    
-    def to_model(self):
-        model = ColorScale(scale_type=self.get_scale_type(),
-                           scale=self.get_scale())
-        return model
-        
-    def set_colorscale(self, colorscale):
-
+    def set_preset(self, colorscale):
+        self.preset_name.setText(colorscale.name)
         self.set_scale_type(colorscale.scale_type)
-        self.set_scale(colorscale.scale)
-        
-    
+        self.set_scale(colorscale.colorscale)
     
+    def get_preset(self):
+        colorscale = ColorScale(scale_type=self.get_scale_type(),
+                                colorscale=self.get_scale(),
+                                name=self.preset_name.text())
+
+        return colorscale
+  
     def get_scale(self):
         for radio, widget in zip(self._get_radios(), self._get_widgets()):
             if radio.isChecked():
                 return widget.values()
             
     def set_scale(self, scale):
-
         for radio, widget in zip(self._get_radios(), self._get_widgets()):
             if radio.isChecked():
                 return widget.setValues(scale)
@@ -535,40 +546,11 @@ class ImagePresetDialog(QDialogBase):
             if radio.isChecked():
                 return stype
     
-    def set_scale_type(self, scale_type):
- 
+    def set_scale_type(self, scale_type): 
         for stype, radio in zip(self._get_scale_types(), self._get_radios()):
             if stype == scale_type:
                 radio.setChecked(True)
 
                 
-  
-        
-    
-        
 
-        
-     
-
-if __name__ == "__main__":
-    #import qdarkstyle
-    from simple_slice_viewer.preset_model import PresetModel
-    presets = PresetModel().load_from_disk(load_defaults=True)
-    
-    app = QApplication([])
-    view = ImageFusionPresetDialog()
-    view.image_preset_combo.addItems(presets.image_presets.get_names())
-    view.fusion_preset_combo.addItems(presets.image_presets.get_names())
-    view.set_preset(presets.image_fusion_presets[0])
-    view.exec_()
-    # contr = ImageFuPresetController()
-    # contr.show_dialog(presets.image_presets[0])
-    # view.save_widget.set_existing_presets([preset.name for preset in presets.image_presets])
-#     view.save_widget.new_input.setText(presets.image_presets.get_new_name())
-    # view.from_model(app.c)
-    # view.from_list(presets.colormaps)
-    
-
-    
-    #model=StyleModel().load_from_disk()
-    #controller = St
\ No newline at end of file
+    
\ No newline at end of file
