@@ -2,33 +2,24 @@ import SimpleITK as sitk
 import sitk_tools
 import pyqtgraph as pg
 import numpy as np
-from functools import partial
 from pyqtgraph import Point
-from PyQt5.QtWidgets import (QWidget, QGridLayout, QLabel, 
-                             QRadioButton, QLineEdit, QDoubleSpinBox,
-                             QApplication, QPushButton, QScrollBar,
-                             QMainWindow, QVBoxLayout,
-                             QHBoxLayout, QStatusBar, QSizePolicy, QComboBox)
-                             
-                           
+from PyQt5.QtWidgets import (QLabel, QRadioButton, QApplication, QPushButton, 
+                             QScrollBar, QMainWindow, QVBoxLayout, QHBoxLayout, 
+                             QStatusBar, QSizePolicy)
+                                                 
 from pyqtgraph import InfiniteLine
-from PyQt5.QtCore import Qt, pyqtSignal
-
-from simple_slice_viewer import model
-#from simple_slice_viewer.menus import Menus
-#from simple_slice_viewer.styles import window_levels, presets, colormap_names
-
+from PyQt5.QtCore import Qt, pyqtSignal, QPointF
 import qtawesome as qta
+
+from simple_slice_viewer.view_base import WidgetBase
+from simple_slice_viewer import model
+from simple_slice_viewer.preset_model import ColorMap
 from simple_slice_viewer import Logger
 
 LOG_LEVEL = Logger.LEVEL_DEBUG
-# callback = lambda _, cmap=cmap: self.set_cmap(cmap)
-# action.triggered.connect(callback)
- 
-# callback = lambda _, wl=wl: self.set_window_level(wl)
-# action.triggered.connect(callback)
 
-from simple_slice_viewer.preset_model import ImagePreset
+
+
 
 
     
@@ -63,7 +54,7 @@ class ColorBarItemMouse(pg.ColorBarItem):
             self.right_clicked.emit()
 
     def setColorMap(self, cmap):
-        cmap = ImagePreset.get_pg_colormap(cmap)
+        cmap = ColorMap.get_pg_colormap(cmap)
         # if sum(cmap[0].getRgb()) == 4:
         #     self.parent.plot_item.getViewBox().setBackgroundColor('w')
         # else:
@@ -71,93 +62,163 @@ class ColorBarItemMouse(pg.ColorBarItem):
            
         super().setColorMap(cmap)
         
-class ImageItemMouse(pg.ImageItem):
+class ViewBoxMouse(pg.ViewBox):
+    key_pressed = pyqtSignal(int)
     right_clicked = pyqtSignal()
-    left_clicked = pyqtSignal(object)
+    left_clicked = pyqtSignal()
+    mouseScroll = pyqtSignal(int)
 
-    def mouseClickEvent(self, event):
+    def keyPressEvent(self, ev):
+        self.key_pressed.emit(ev.key())
+     
+
+    def wheelEvent(self, event, axis=None):     
+
+        event.accept()
+        delta = event.delta() // 120
+        self.mouseScroll.emit(delta)
+
+ #   def mouseClickEvent(self, ev):
+        
+    
+    def mouseDragEvent(self, ev):
+    
+        if ev.button() == Qt.LeftButton:
+            return
+        else:
+            super().mouseDragEvent(ev)
+            
+    # def mouseDragEvent(self, ev, axis=None):
+    #     if ev.button() == Qt.LeftButton:
+    #         print('drag')
+    #     else:
+    #         return super().mouseDragEvent(ev, axis=axis)
+
+class ImageItemMouse(pg.ImageItem):
+    left_clicked = pyqtSignal(object)
+    right_clicked = pyqtSignal(object)
+    mouseScroll = pyqtSignal(int)
+    
+    def mouseClickEvent(self, event, axis=None):
 
         if event.button() == Qt.RightButton:            
-            self.right_clicked.emit()
+            self.right_clicked.emit(event.pos())
         elif event.button() == Qt.LeftButton:
-
             self.left_clicked.emit(event.pos())
-        
-class WidgetBase(QWidget):
-    _layout = None
-    def __init__(self, parent=None):
-        QWidget.__init__(self, parent)
-        self.create_widgets()
-        self.create_layout()
-        self.create_bottom_layout()
-        self.set_callbacks()
-        self.setLayout(self.layout)
-        self.set_widgets()
-        
-    def create_widgets(self):
-        pass
     
-    def create_layout(self):
-        pass
-    
-    def create_bottom_layout(self):
-        pass
-    
-    def set_callbacks(self):
-        pass
-    
-    def set_widgets(self):
-        pass
 
-    @property
-    def layout(self):
-        if self._layout is None:
-            self._layout = self._get_layout_object()
-        return self._layout
-    
-    @layout.setter
-    def layout(self, layout):
-        self._layout = layout
-        
-    
-    def _get_layout_object(self):
-        return QGridLayout()
-    
-    @staticmethod
-    def set_combo_to_text(combo, text):
-        combo.setCurrentIndex(combo.findText(str(text)))
 
+class InfiniteLine(InfiniteLine):
+    _drag_position = QPointF(0, 0)
+    _hoverEvent = pyqtSignal(bool)
+    
+    # def mousePressEvent(self, ev):
+    #     print('click')
+    #     super().mousePressEvent(ev)
+    
+    def setMouseHover(self, hover): 
+        if self.moving:
+            hover = True
+        emit =  self.mouseHovering != hover
+            
+        super().setMouseHover(hover)
+        
+        if emit:
+            self._hoverEvent.emit(hover)
+            
+    def mouseDragEvent(self, ev):
+        self._drag_position = self.getViewBox().mapSceneToView(ev.scenePos())        
+        super().mouseDragEvent(ev)
+        
+   
+                
 class CrossHairView(WidgetBase):
     positionChanged = pyqtSignal(Point)
+    visibleChanged = pyqtSignal(bool)
     # def __init__(self, *args, view_item=None, **kwargs):
     #     self.view_item = view_item
         
-    #     super().__init__(*args, **kwargs)
+    def __init__(self, *args, plot_item=None, **kwargs):        
+        super().__init__(*args, **kwargs)        
+        plot_item.addItem(self.vertical_line)
+        plot_item.addItem(self.horizontal_line)
+
+        self.plot_item = plot_item
+        self.set_viewbox_callbacks()
+        
+        
+        
+    def get_lines(self):
+        return [self.horizontal_line, self.vertical_line]
     
+    def set_viewbox_callbacks(self):
+        self.vertical_line.getViewBox().key_pressed.connect(self.key_press)
+    def set_callbacks(self):         
+        for line in self.get_lines():
+            line.sigDragged.connect(self.drag)                       
+            line.sigPositionChangeFinished.connect(self.drag_finished)            
+            line._hoverEvent.connect(self.update_hover)
+            line.sigPositionChanged.connect(self.position_changed)
+            
+    def key_press(self, key):
+        if key == Qt.Key_C:
+            self.set_visible()
+            
+    def drag(self, line):        
+        self.horizontal_line.moving = True
+        self.vertical_line.moving = True
+        pos = line._drag_position
+        if line == self.horizontal_line:
+            self.vertical_line.setValue(pos.x())
+        elif line == self.vertical_line:
+            self.horizontal_line.setValue(pos.y())
+        self.position_changed()
+        
+    def drag_finished(self, line):
+        self.drag(line)
+        self.vertical_line.moving = False
+        self.horizontal_line.moving = False
+                
+        
     def create_widgets(self):
-        self.horizontal_line = InfiniteLine(angle=0)
-        self.vertical_line = InfiniteLine(angle=90)
+        self.horizontal_line = InfiniteLine(angle=0, movable=True)
+        self.vertical_line = InfiniteLine(angle=90, movable=True)
+
+    def update_hover(self, hover):
+        
+        lines = [self.horizontal_line, self.vertical_line]
+
+        for line in lines:
+            line.setMouseHover(hover)
     
-    def set_visible(self, visible):
-        self.horizontal_line.setVisible(visible)
-        self.vertical_line.setVisible(visible)
+    def is_visible(self):
+        return self.horizontal_line.isVisible()
+        
+    def set_visible(self, visible=None):
+        if visible is None:
+            visible = not self.is_visible()
+        
+        if visible == self.is_visible():
+            return
+            
+        for line in self.get_lines():
+            line.setVisible(visible)
+        
+        self.visibleChanged.emit(self.is_visible())
         
     def set_position(self, pos):
         self.vertical_line.setValue(pos[0])
         self.horizontal_line.setValue(pos[1])
     
-    def set_widgets(self):
-        self.vertical_line.sigPositionChanged.connect(self.position_changed)
-        self.horizontal_line.sigPositionChanged.connect(self.position_changed)
-    
     def get_position(self):
         return Point(self.vertical_line.value(), 
                        self.horizontal_line.value())
     
-    def position_changed(self, obj):
+    def position_changed(self, obj=None):
         self.positionChanged.emit(self.get_position())
         
 
+        
 class ImageWidget(WidgetBase):    
 
     _image = None
@@ -179,8 +240,10 @@ class ImageWidget(WidgetBase):
         self.crosshair.set_position(pos_index)
     
     def create_widgets(self):
+        self.view_box = ViewBoxMouse()
 
-        self.plot_item = pg.PlotItem()
+        self.plot_item = pg.PlotItem(viewBox=self.view_box,
+                                     mouse_enabled=False)
         self.plot_item.setMenuEnabled(False)
         
         vb = self.plot_item.getViewBox()
@@ -188,12 +251,14 @@ class ImageWidget(WidgetBase):
         
         
         self.image_item = ImageItemMouse(image=self.get_np_image(), 
-                                            parent=self.plot_item)
+                                         parent=self.plot_item)
+                                            
+        
         
-        self.crosshair = CrossHairView()
         
         self.fusion_item = pg.ImageItem(image=self.get_np_fusion(), 
-                                        parent=self.plot_item)
+                                        parent=self.plot_item,
+                                        mouse_enabled=False)
         
         self.fusion_item.setZValue(10)
         
@@ -207,19 +272,13 @@ class ImageWidget(WidgetBase):
         self.plot_item.hideAxis('bottom')
         self.plot_item.hideAxis('left')
         
-        
-    def set_widgets(self):
-        self.plot_item.addItem(self.crosshair.vertical_line)
-        self.plot_item.addItem(self.crosshair.horizontal_line)
-        
-   
-    def create_layout(self):
-        
         self.plot_item.addItem(self.image_item)
         self.plot_item.addItem(self.fusion_item)
+        self.crosshair = CrossHairView(plot_item=self.plot_item)
         
-        
-        
+
+    def create_layout(self):
+     
         self.layout = QHBoxLayout()
         self.glayout = pg.GraphicsLayoutWidget()
         
@@ -333,13 +392,13 @@ class ButtonView(WidgetBase):
     label_text = 'Button Group Name'
     orientation = Qt.Horizontal
 
-    def __init__(self, parent=None, button_texts=None, label_text=None):
+    def __init__(self, parent=None, button_texts=None, **kwargs):
         
         if button_texts is not None:
             self.button_texts = button_texts
-            
-        if label_text is not None:
-            self.label_text = label_text
+        
+        if 'label_text' in kwargs.keys():
+            self.label_text = kwargs['label_text']
             
         WidgetBase.__init__(self, parent=parent)
 
@@ -481,46 +540,57 @@ class OperatorButtons(ButtonView):
     label_text = 'Image <operator> Fusion'
     
     
+
     
-class VerticalSLider(WidgetBase):
+  
+class HorizontalSLider(WidgetBase):
+    ORIENTATION = Qt.Horizontal
     def __init__(self, parent=None, label='Alpha', unit='%', value=50):
         self.label = label
         self.unit = unit
-        self._value = value
+        
         super().__init__(parent=parent)
         
-
-    @property
-    def value(self):
-        return str(self._value)
+        self.setValue(value)
     
-    @value.setter
-    def value(self, value):
+    def value(self):
+        return self.scrollbar.value()
+    
+   
+    def setValue(self, value):
         value = str(value)
-        self._value = value
-        self.top_label.setText(value + self.unit)
+        self.scrollbar.setValue(int(value))
+        self.update_label()
+
 
         
     def create_widgets(self):
         self.label = QLabel(self.label)
-        self.top_label = QLabel(self.value)
-        self.scrollbar = QScrollBar(orientation = Qt.Vertical)
+        self.top_label = QLabel(str(self.value))
+        self.scrollbar = QScrollBar(orientation = self.ORIENTATION)
         
         
     def create_layout(self):
-        self.layout = QVBoxLayout()
-        self.layout.addWidget(self.label, 0, alignment=Qt.AlignHCenter)
-        self.layout.addWidget(self.top_label, 0, alignment=Qt.AlignCenter)
-        self.layout.addWidget(self.scrollbar, 1,  alignment=Qt.AlignHCenter)
+        if self.ORIENTATION == Qt.Vertical:
+            self.layout = QVBoxLayout()
+            alignment = Qt.AlignHCenter
+        elif self.ORIENTATION == Qt.Horizontal:
+            self.layout = QHBoxLayout()
+            alignment=Qt.AlignVCenter
+            
+        self.layout.addWidget(self.label, 0, alignment=alignment)
+        self.layout.addWidget(self.top_label, 0, alignment=alignment)
+        self.layout.addWidget(self.scrollbar, 1,  alignment=alignment)
         
     def set_callbacks(self):
-        self.scrollbar.valueChanged.connect(self.scroll_event)
+        self.scrollbar.valueChanged.connect(self.update_label)
         
-    def scroll_event(self, event_data=None):
-        self.value = self.scrollbar.value()
+    def update_label(self, event_data=None):
+        self.top_label.setText(str(self.value()) + self.unit)
         
 
-
+class VerticalSLider(HorizontalSLider):
+    ORIENTATION = Qt.Vertical
     
     
         
