@@ -1,10 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
-Created on Tue Aug 16 11:01:56 2022
-
-@author: 757021
-"""
-
-from sitk_tools.image import *
 from sitk_tools.statistics import *
+from sitk_tools.image import *
+from sitk_tools.suv import *
 from sitk_tools.dicom_reader import *
